django\_page\_hits package
==========================

Subpackages
-----------

.. toctree::

    django_page_hits.migrations
    django_page_hits.tests

Submodules
----------

django\_page\_hits.admin module
-------------------------------

.. automodule:: django_page_hits.admin
    :members:
    :undoc-members:
    :show-inheritance:

django\_page\_hits.apps module
------------------------------

.. automodule:: django_page_hits.apps
    :members:
    :undoc-members:
    :show-inheritance:

django\_page\_hits.middleware module
------------------------------------

.. automodule:: django_page_hits.middleware
    :members:
    :undoc-members:
    :show-inheritance:

django\_page\_hits.models module
--------------------------------

.. automodule:: django_page_hits.models
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: django_page_hits
    :members:
    :undoc-members:
    :show-inheritance:
